# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PutDataRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vector': 'list[FusionFeature]',
        'fusion_rule': 'str'
    }

    attribute_map = {
        'vector': 'vector',
        'fusion_rule': 'fusionRule'
    }

    def __init__(self, vector=None, fusion_rule='default'):
        """PutDataRequest - a model defined in Swagger"""
        self._vector = None
        self._fusion_rule = None
        self.discriminator = None
        self.vector = vector
        if fusion_rule is not None:
            self.fusion_rule = fusion_rule

    @property
    def vector(self):
        """Gets the vector of this PutDataRequest.

        Updates to apply to the current fusion vector.

        :return: The vector of this PutDataRequest.
        :rtype: list[FusionFeature]
        """
        return self._vector

    @vector.setter
    def vector(self, vector):
        """Sets the vector of this PutDataRequest.

        Updates to apply to the current fusion vector.

        :param vector: The vector of this PutDataRequest.
        :type: list[FusionFeature]
        """
        if vector is None:
            raise ValueError("Invalid value for `vector`, must not be `None`")

        self._vector = vector

    @property
    def fusion_rule(self):
        """Gets the fusion_rule of this PutDataRequest.

        If `submit`, the fusion vector will be submitted for inference on this request. If `nosubmit`, this request will not trigger an inference. If `default`, follow the rules for the submitted features.

        :return: The fusion_rule of this PutDataRequest.
        :rtype: str
        """
        return self._fusion_rule

    @fusion_rule.setter
    def fusion_rule(self, fusion_rule):
        """Sets the fusion_rule of this PutDataRequest.

        If `submit`, the fusion vector will be submitted for inference on this request. If `nosubmit`, this request will not trigger an inference. If `default`, follow the rules for the submitted features.

        :param fusion_rule: The fusion_rule of this PutDataRequest.
        :type: str
        """
        allowed_values = ["default", "submit", "nosubmit"]
        if fusion_rule not in allowed_values:
            raise ValueError(
                "Invalid value for `fusion_rule` ({0}), must be one of {1}"
                .format(fusion_rule, allowed_values)
            )

        self._fusion_rule = fusion_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PutDataRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PutDataRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MBufferStats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'VersionNumber',
        'total_bytes_written': 'float',
        'total_bytes_processed': 'float',
        'load_buffer_length': 'float',
        'load_buffer_capacity': 'float'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'total_bytes_written': 'TotalBytesWritten',
        'total_bytes_processed': 'TotalBytesProcessed',
        'load_buffer_length': 'LoadBufferLength',
        'load_buffer_capacity': 'LoadBufferCapacity'
    }

    def __init__(self, version_number=None, total_bytes_written=None, total_bytes_processed=None, load_buffer_length=None, load_buffer_capacity=None):
        """MBufferStats - a model defined in Swagger"""
        self._version_number = None
        self._total_bytes_written = None
        self._total_bytes_processed = None
        self._load_buffer_length = None
        self._load_buffer_capacity = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        if total_bytes_written is not None:
            self.total_bytes_written = total_bytes_written
        if total_bytes_processed is not None:
            self.total_bytes_processed = total_bytes_processed
        if load_buffer_length is not None:
            self.load_buffer_length = load_buffer_length
        if load_buffer_capacity is not None:
            self.load_buffer_capacity = load_buffer_capacity

    @property
    def version_number(self):
        """Gets the version_number of this MBufferStats.


        :return: The version_number of this MBufferStats.
        :rtype: VersionNumber
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MBufferStats.


        :param version_number: The version_number of this MBufferStats.
        :type: VersionNumber
        """

        self._version_number = version_number

    @property
    def total_bytes_written(self):
        """Gets the total_bytes_written of this MBufferStats.


        :return: The total_bytes_written of this MBufferStats.
        :rtype: float
        """
        return self._total_bytes_written

    @total_bytes_written.setter
    def total_bytes_written(self, total_bytes_written):
        """Sets the total_bytes_written of this MBufferStats.


        :param total_bytes_written: The total_bytes_written of this MBufferStats.
        :type: float
        """

        self._total_bytes_written = total_bytes_written

    @property
    def total_bytes_processed(self):
        """Gets the total_bytes_processed of this MBufferStats.


        :return: The total_bytes_processed of this MBufferStats.
        :rtype: float
        """
        return self._total_bytes_processed

    @total_bytes_processed.setter
    def total_bytes_processed(self, total_bytes_processed):
        """Sets the total_bytes_processed of this MBufferStats.


        :param total_bytes_processed: The total_bytes_processed of this MBufferStats.
        :type: float
        """

        self._total_bytes_processed = total_bytes_processed

    @property
    def load_buffer_length(self):
        """Gets the load_buffer_length of this MBufferStats.


        :return: The load_buffer_length of this MBufferStats.
        :rtype: float
        """
        return self._load_buffer_length

    @load_buffer_length.setter
    def load_buffer_length(self, load_buffer_length):
        """Sets the load_buffer_length of this MBufferStats.


        :param load_buffer_length: The load_buffer_length of this MBufferStats.
        :type: float
        """

        self._load_buffer_length = load_buffer_length

    @property
    def load_buffer_capacity(self):
        """Gets the load_buffer_capacity of this MBufferStats.


        :return: The load_buffer_capacity of this MBufferStats.
        :rtype: float
        """
        return self._load_buffer_capacity

    @load_buffer_capacity.setter
    def load_buffer_capacity(self, load_buffer_capacity):
        """Sets the load_buffer_capacity of this MBufferStats.


        :param load_buffer_capacity: The load_buffer_capacity of this MBufferStats.
        :type: float
        """

        self._load_buffer_capacity = load_buffer_capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MBufferStats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MBufferStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MAP(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'VersionNumber',
        'm_autotune_range': 'bool',
        'm_autotune_pv': 'bool',
        'm_autotune_by_features': 'bool',
        'm_max_clusters': 'float',
        'm_features_to_tune_array': 'list[float]'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'm_autotune_range': 'm_AutotuneRange',
        'm_autotune_pv': 'm_AutotunePV',
        'm_autotune_by_features': 'm_AutotuneByFeatures',
        'm_max_clusters': 'm_MaxClusters',
        'm_features_to_tune_array': 'm_FeaturesToTuneArray'
    }

    def __init__(self, version_number=None, m_autotune_range=None, m_autotune_pv=None, m_autotune_by_features=None, m_max_clusters=None, m_features_to_tune_array=None):
        """MAP - a model defined in Swagger"""
        self._version_number = None
        self._m_autotune_range = None
        self._m_autotune_pv = None
        self._m_autotune_by_features = None
        self._m_max_clusters = None
        self._m_features_to_tune_array = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        self.m_autotune_range = m_autotune_range
        self.m_autotune_pv = m_autotune_pv
        self.m_autotune_by_features = m_autotune_by_features
        if m_max_clusters is not None:
            self.m_max_clusters = m_max_clusters
        if m_features_to_tune_array is not None:
            self.m_features_to_tune_array = m_features_to_tune_array

    @property
    def version_number(self):
        """Gets the version_number of this MAP.


        :return: The version_number of this MAP.
        :rtype: VersionNumber
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MAP.


        :param version_number: The version_number of this MAP.
        :type: VersionNumber
        """

        self._version_number = version_number

    @property
    def m_autotune_range(self):
        """Gets the m_autotune_range of this MAP.


        :return: The m_autotune_range of this MAP.
        :rtype: bool
        """
        return self._m_autotune_range

    @m_autotune_range.setter
    def m_autotune_range(self, m_autotune_range):
        """Sets the m_autotune_range of this MAP.


        :param m_autotune_range: The m_autotune_range of this MAP.
        :type: bool
        """
        if m_autotune_range is None:
            raise ValueError("Invalid value for `m_autotune_range`, must not be `None`")

        self._m_autotune_range = m_autotune_range

    @property
    def m_autotune_pv(self):
        """Gets the m_autotune_pv of this MAP.


        :return: The m_autotune_pv of this MAP.
        :rtype: bool
        """
        return self._m_autotune_pv

    @m_autotune_pv.setter
    def m_autotune_pv(self, m_autotune_pv):
        """Sets the m_autotune_pv of this MAP.


        :param m_autotune_pv: The m_autotune_pv of this MAP.
        :type: bool
        """
        if m_autotune_pv is None:
            raise ValueError("Invalid value for `m_autotune_pv`, must not be `None`")

        self._m_autotune_pv = m_autotune_pv

    @property
    def m_autotune_by_features(self):
        """Gets the m_autotune_by_features of this MAP.


        :return: The m_autotune_by_features of this MAP.
        :rtype: bool
        """
        return self._m_autotune_by_features

    @m_autotune_by_features.setter
    def m_autotune_by_features(self, m_autotune_by_features):
        """Sets the m_autotune_by_features of this MAP.


        :param m_autotune_by_features: The m_autotune_by_features of this MAP.
        :type: bool
        """
        if m_autotune_by_features is None:
            raise ValueError("Invalid value for `m_autotune_by_features`, must not be `None`")

        self._m_autotune_by_features = m_autotune_by_features

    @property
    def m_max_clusters(self):
        """Gets the m_max_clusters of this MAP.


        :return: The m_max_clusters of this MAP.
        :rtype: float
        """
        return self._m_max_clusters

    @m_max_clusters.setter
    def m_max_clusters(self, m_max_clusters):
        """Sets the m_max_clusters of this MAP.


        :param m_max_clusters: The m_max_clusters of this MAP.
        :type: float
        """

        self._m_max_clusters = m_max_clusters

    @property
    def m_features_to_tune_array(self):
        """Gets the m_features_to_tune_array of this MAP.


        :return: The m_features_to_tune_array of this MAP.
        :rtype: list[float]
        """
        return self._m_features_to_tune_array

    @m_features_to_tune_array.setter
    def m_features_to_tune_array(self, m_features_to_tune_array):
        """Sets the m_features_to_tune_array of this MAP.


        :param m_features_to_tune_array: The m_features_to_tune_array of this MAP.
        :type: list[float]
        """

        self._m_features_to_tune_array = m_features_to_tune_array

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MAP, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MAP):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ConfigResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'streaming_window': 'StreamingWindow',
        'percent_variation': 'PercentVariation',
        'features': 'list[FeatureConfigResponse]',
        'training': 'TrainingConfig',
        'autotuning': 'Autotuning'
    }

    attribute_map = {
        'streaming_window': 'streamingWindow',
        'percent_variation': 'percentVariation',
        'features': 'features',
        'training': 'training',
        'autotuning': 'autotuning'
    }

    def __init__(self, streaming_window=None, percent_variation=None, features=None, training=None, autotuning=None):
        """ConfigResponse - a model defined in Swagger"""
        self._streaming_window = None
        self._percent_variation = None
        self._features = None
        self._training = None
        self._autotuning = None
        self.discriminator = None
        if streaming_window is not None:
            self.streaming_window = streaming_window
        if percent_variation is not None:
            self.percent_variation = percent_variation
        if features is not None:
            self.features = features
        if training is not None:
            self.training = training
        if autotuning is not None:
            self.autotuning = autotuning

    @property
    def streaming_window(self):
        """Gets the streaming_window of this ConfigResponse.


        :return: The streaming_window of this ConfigResponse.
        :rtype: StreamingWindow
        """
        return self._streaming_window

    @streaming_window.setter
    def streaming_window(self, streaming_window):
        """Sets the streaming_window of this ConfigResponse.


        :param streaming_window: The streaming_window of this ConfigResponse.
        :type: StreamingWindow
        """

        self._streaming_window = streaming_window

    @property
    def percent_variation(self):
        """Gets the percent_variation of this ConfigResponse.


        :return: The percent_variation of this ConfigResponse.
        :rtype: PercentVariation
        """
        return self._percent_variation

    @percent_variation.setter
    def percent_variation(self, percent_variation):
        """Sets the percent_variation of this ConfigResponse.


        :param percent_variation: The percent_variation of this ConfigResponse.
        :type: PercentVariation
        """

        self._percent_variation = percent_variation

    @property
    def features(self):
        """Gets the features of this ConfigResponse.


        :return: The features of this ConfigResponse.
        :rtype: list[FeatureConfigResponse]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this ConfigResponse.


        :param features: The features of this ConfigResponse.
        :type: list[FeatureConfigResponse]
        """

        self._features = features

    @property
    def training(self):
        """Gets the training of this ConfigResponse.


        :return: The training of this ConfigResponse.
        :rtype: TrainingConfig
        """
        return self._training

    @training.setter
    def training(self, training):
        """Sets the training of this ConfigResponse.


        :param training: The training of this ConfigResponse.
        :type: TrainingConfig
        """

        self._training = training

    @property
    def autotuning(self):
        """Gets the autotuning of this ConfigResponse.


        :return: The autotuning of this ConfigResponse.
        :rtype: Autotuning
        """
        return self._autotuning

    @autotuning.setter
    def autotuning(self, autotuning):
        """Sets the autotuning of this ConfigResponse.


        :param autotuning: The autotuning of this ConfigResponse.
        :type: Autotuning
        """

        self._autotuning = autotuning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConfigResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MNanoBackend(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'VersionNumber',
        'm_pattern_memory': 'MPatternMemory',
        'm_init_complete': 'bool',
        'm_pattern_length': 'float',
        'm_learning_is_on': 'bool',
        'm_num_of_patterns_clustered': 'float'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'm_pattern_memory': 'm_PatternMemory',
        'm_init_complete': 'm_InitComplete',
        'm_pattern_length': 'm_PatternLength',
        'm_learning_is_on': 'm_LearningIsOn',
        'm_num_of_patterns_clustered': 'm_NumOfPatternsClustered'
    }

    def __init__(self, version_number=None, m_pattern_memory=None, m_init_complete=None, m_pattern_length=None, m_learning_is_on=None, m_num_of_patterns_clustered=None):
        """MNanoBackend - a model defined in Swagger"""
        self._version_number = None
        self._m_pattern_memory = None
        self._m_init_complete = None
        self._m_pattern_length = None
        self._m_learning_is_on = None
        self._m_num_of_patterns_clustered = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        if m_pattern_memory is not None:
            self.m_pattern_memory = m_pattern_memory
        if m_init_complete is not None:
            self.m_init_complete = m_init_complete
        if m_pattern_length is not None:
            self.m_pattern_length = m_pattern_length
        if m_learning_is_on is not None:
            self.m_learning_is_on = m_learning_is_on
        if m_num_of_patterns_clustered is not None:
            self.m_num_of_patterns_clustered = m_num_of_patterns_clustered

    @property
    def version_number(self):
        """Gets the version_number of this MNanoBackend.


        :return: The version_number of this MNanoBackend.
        :rtype: VersionNumber
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MNanoBackend.


        :param version_number: The version_number of this MNanoBackend.
        :type: VersionNumber
        """

        self._version_number = version_number

    @property
    def m_pattern_memory(self):
        """Gets the m_pattern_memory of this MNanoBackend.


        :return: The m_pattern_memory of this MNanoBackend.
        :rtype: MPatternMemory
        """
        return self._m_pattern_memory

    @m_pattern_memory.setter
    def m_pattern_memory(self, m_pattern_memory):
        """Sets the m_pattern_memory of this MNanoBackend.


        :param m_pattern_memory: The m_pattern_memory of this MNanoBackend.
        :type: MPatternMemory
        """

        self._m_pattern_memory = m_pattern_memory

    @property
    def m_init_complete(self):
        """Gets the m_init_complete of this MNanoBackend.


        :return: The m_init_complete of this MNanoBackend.
        :rtype: bool
        """
        return self._m_init_complete

    @m_init_complete.setter
    def m_init_complete(self, m_init_complete):
        """Sets the m_init_complete of this MNanoBackend.


        :param m_init_complete: The m_init_complete of this MNanoBackend.
        :type: bool
        """

        self._m_init_complete = m_init_complete

    @property
    def m_pattern_length(self):
        """Gets the m_pattern_length of this MNanoBackend.


        :return: The m_pattern_length of this MNanoBackend.
        :rtype: float
        """
        return self._m_pattern_length

    @m_pattern_length.setter
    def m_pattern_length(self, m_pattern_length):
        """Sets the m_pattern_length of this MNanoBackend.


        :param m_pattern_length: The m_pattern_length of this MNanoBackend.
        :type: float
        """

        self._m_pattern_length = m_pattern_length

    @property
    def m_learning_is_on(self):
        """Gets the m_learning_is_on of this MNanoBackend.


        :return: The m_learning_is_on of this MNanoBackend.
        :rtype: bool
        """
        return self._m_learning_is_on

    @m_learning_is_on.setter
    def m_learning_is_on(self, m_learning_is_on):
        """Sets the m_learning_is_on of this MNanoBackend.


        :param m_learning_is_on: The m_learning_is_on of this MNanoBackend.
        :type: bool
        """

        self._m_learning_is_on = m_learning_is_on

    @property
    def m_num_of_patterns_clustered(self):
        """Gets the m_num_of_patterns_clustered of this MNanoBackend.


        :return: The m_num_of_patterns_clustered of this MNanoBackend.
        :rtype: float
        """
        return self._m_num_of_patterns_clustered

    @m_num_of_patterns_clustered.setter
    def m_num_of_patterns_clustered(self, m_num_of_patterns_clustered):
        """Sets the m_num_of_patterns_clustered of this MNanoBackend.


        :param m_num_of_patterns_clustered: The m_num_of_patterns_clustered of this MNanoBackend.
        :type: float
        """

        self._m_num_of_patterns_clustered = m_num_of_patterns_clustered

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MNanoBackend, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MNanoBackend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FeatureConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'min_val': 'float',
        'max_val': 'float',
        'weight': 'int',
        'fusion_rule': 'str',
        'fusion_ttl': 'int'
    }

    attribute_map = {
        'name': 'name',
        'min_val': 'minVal',
        'max_val': 'maxVal',
        'weight': 'weight',
        'fusion_rule': 'fusionRule',
        'fusion_ttl': 'fusionTTL'
    }

    def __init__(self, name=None, min_val=None, max_val=None, weight=None, fusion_rule='submit', fusion_ttl=None):
        """FeatureConfig - a model defined in Swagger"""
        self._name = None
        self._min_val = None
        self._max_val = None
        self._weight = None
        self._fusion_rule = None
        self._fusion_ttl = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if min_val is not None:
            self.min_val = min_val
        if max_val is not None:
            self.max_val = max_val
        if weight is not None:
            self.weight = weight
        if fusion_rule is not None:
            self.fusion_rule = fusion_rule
        if fusion_ttl is not None:
            self.fusion_ttl = fusion_ttl

    @property
    def name(self):
        """Gets the name of this FeatureConfig.

        Name for this feature. Must be unique with respect to other features in the configuration. Regex: `^[A-Za-z0-9.:_-]{1,1024}$`.

        :return: The name of this FeatureConfig.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FeatureConfig.

        Name for this feature. Must be unique with respect to other features in the configuration. Regex: `^[A-Za-z0-9.:_-]{1,1024}$`.

        :param name: The name of this FeatureConfig.
        :type: str
        """

        self._name = name

    @property
    def min_val(self):
        """Gets the min_val of this FeatureConfig.

        Minimum expected value for this feature. `minVal` can be left unset if it is not known at configuration time. In that case, data collected during the `Buffering` stage will be used to infer an optimal `minVal` during the `Autotuning` stage and it will be set to the autotuned value at the start of `Learning`.

        :return: The min_val of this FeatureConfig.
        :rtype: float
        """
        return self._min_val

    @min_val.setter
    def min_val(self, min_val):
        """Sets the min_val of this FeatureConfig.

        Minimum expected value for this feature. `minVal` can be left unset if it is not known at configuration time. In that case, data collected during the `Buffering` stage will be used to infer an optimal `minVal` during the `Autotuning` stage and it will be set to the autotuned value at the start of `Learning`.

        :param min_val: The min_val of this FeatureConfig.
        :type: float
        """

        self._min_val = min_val

    @property
    def max_val(self):
        """Gets the max_val of this FeatureConfig.

        Maximum expected value for this feature. `maxVal` can be left unset if it is not known at configuration time. In that case, data collected during the `Buffering` stage will be used to infer an optimal value during the `Autotuning` stage and it will be set to the autotuned value at the start of `Learning`.

        :return: The max_val of this FeatureConfig.
        :rtype: float
        """
        return self._max_val

    @max_val.setter
    def max_val(self, max_val):
        """Sets the max_val of this FeatureConfig.

        Maximum expected value for this feature. `maxVal` can be left unset if it is not known at configuration time. In that case, data collected during the `Buffering` stage will be used to infer an optimal value during the `Autotuning` stage and it will be set to the autotuned value at the start of `Learning`.

        :param max_val: The max_val of this FeatureConfig.
        :type: float
        """

        self._max_val = max_val

    @property
    def weight(self):
        """Gets the weight of this FeatureConfig.

        Weight of this feature relative to others, as an integer between 1 and 1000.

        :return: The weight of this FeatureConfig.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this FeatureConfig.

        Weight of this feature relative to others, as an integer between 1 and 1000.

        :param weight: The weight of this FeatureConfig.
        :type: int
        """

        self._weight = weight

    @property
    def fusion_rule(self):
        """Gets the fusion_rule of this FeatureConfig.

        Inference policy for the fusion vector when using `PUT /data`. If `submit`, any `PUT /data` request that updates this feature will cause the fusion vector to be submitted for inference. If `nosubmit`, updates to this feature will not trigger a fusion vector inference.

        :return: The fusion_rule of this FeatureConfig.
        :rtype: str
        """
        return self._fusion_rule

    @fusion_rule.setter
    def fusion_rule(self, fusion_rule):
        """Sets the fusion_rule of this FeatureConfig.

        Inference policy for the fusion vector when using `PUT /data`. If `submit`, any `PUT /data` request that updates this feature will cause the fusion vector to be submitted for inference. If `nosubmit`, updates to this feature will not trigger a fusion vector inference.

        :param fusion_rule: The fusion_rule of this FeatureConfig.
        :type: str
        """
        allowed_values = ["submit", "nosubmit"]
        if fusion_rule not in allowed_values:
            raise ValueError(
                "Invalid value for `fusion_rule` ({0}), must be one of {1}"
                .format(fusion_rule, allowed_values)
            )

        self._fusion_rule = fusion_rule

    @property
    def fusion_ttl(self):
        """Gets the fusion_ttl of this FeatureConfig.

        Number of seconds without an update before this feature's value is considered invalid.

        :return: The fusion_ttl of this FeatureConfig.
        :rtype: int
        """
        return self._fusion_ttl

    @fusion_ttl.setter
    def fusion_ttl(self, fusion_ttl):
        """Sets the fusion_ttl of this FeatureConfig.

        Number of seconds without an update before this feature's value is considered invalid.

        :param fusion_ttl: The fusion_ttl of this FeatureConfig.
        :type: int
        """

        self._fusion_ttl = fusion_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeatureConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from boonamber.v2.api.default_api import DefaultApi
# import ApiClient
from boonamber.v2.api_client import ApiClient
from boonamber.v2.configuration import Configuration
# import models into sdk package
from boonamber.v2.models.amber_state import AmberState
from boonamber.v2.models.analytic_results import AnalyticResults
from boonamber.v2.models.autotuning import Autotuning
from boonamber.v2.models.config_response import ConfigResponse
from boonamber.v2.models.delete_model_response import DeleteModelResponse
from boonamber.v2.models.error import Error
from boonamber.v2.models.feature_config import FeatureConfig
from boonamber.v2.models.feature_config_response import FeatureConfigResponse
from boonamber.v2.models.feature_root_cause import FeatureRootCause
from boonamber.v2.models.fusion_feature import FusionFeature
from boonamber.v2.models.get_models_response import GetModelsResponse
from boonamber.v2.models.get_nano_status_response import GetNanoStatusResponse
from boonamber.v2.models.get_pretrain_response import GetPretrainResponse
from boonamber.v2.models.get_root_cause_response import GetRootCauseResponse
from boonamber.v2.models.get_status_response import GetStatusResponse
from boonamber.v2.models.get_summary_response import GetSummaryResponse
from boonamber.v2.models.get_version_response import GetVersionResponse
from boonamber.v2.models.model import Model
from boonamber.v2.models.model_status import ModelStatus
from boonamber.v2.models.nano_status import NanoStatus
from boonamber.v2.models.percent_variation import PercentVariation
from boonamber.v2.models.post_config_request import PostConfigRequest
from boonamber.v2.models.post_config_response import PostConfigResponse
from boonamber.v2.models.post_data_request import PostDataRequest
from boonamber.v2.models.post_data_response import PostDataResponse
from boonamber.v2.models.post_learning_request import PostLearningRequest
from boonamber.v2.models.post_learning_response import PostLearningResponse
from boonamber.v2.models.post_model_copy_request import PostModelCopyRequest
from boonamber.v2.models.post_model_request import PostModelRequest
from boonamber.v2.models.post_model_response import PostModelResponse
from boonamber.v2.models.post_oauth2_access_request import PostOauth2AccessRequest
from boonamber.v2.models.post_oauth2_access_response import PostOauth2AccessResponse
from boonamber.v2.models.post_oauth2_refresh_request import PostOauth2RefreshRequest
from boonamber.v2.models.post_oauth2_refresh_response import PostOauth2RefreshResponse
from boonamber.v2.models.post_pretrain_request import PostPretrainRequest
from boonamber.v2.models.post_pretrain_response import PostPretrainResponse
from boonamber.v2.models.pretrain_status import PretrainStatus
from boonamber.v2.models.put_data_request import PutDataRequest
from boonamber.v2.models.put_data_response import PutDataResponse
from boonamber.v2.models.put_model_request import PutModelRequest
from boonamber.v2.models.streaming_window import StreamingWindow
from boonamber.v2.models.training_config import TrainingConfig



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'state': 'AmberState',
        'warning_level': 'int',
        'sample_count': 'int',
        'cluster_count': 'int',
        'progress': 'int',
        'message': 'str',
        'last_modified': 'int',
        'last_modified_delta': 'int'
    }

    attribute_map = {
        'state': 'state',
        'warning_level': 'warningLevel',
        'sample_count': 'sampleCount',
        'cluster_count': 'clusterCount',
        'progress': 'progress',
        'message': 'message',
        'last_modified': 'lastModified',
        'last_modified_delta': 'lastModifiedDelta'
    }

    def __init__(self, state=None, warning_level=None, sample_count=None, cluster_count=None, progress=None, message=None, last_modified=None, last_modified_delta=None):
        """ModelStatus - a model defined in Swagger"""
        self._state = None
        self._warning_level = None
        self._sample_count = None
        self._cluster_count = None
        self._progress = None
        self._message = None
        self._last_modified = None
        self._last_modified_delta = None
        self.discriminator = None
        if state is not None:
            self.state = state
        if warning_level is not None:
            self.warning_level = warning_level
        if sample_count is not None:
            self.sample_count = sample_count
        if cluster_count is not None:
            self.cluster_count = cluster_count
        if progress is not None:
            self.progress = progress
        if message is not None:
            self.message = message
        if last_modified is not None:
            self.last_modified = last_modified
        if last_modified_delta is not None:
            self.last_modified_delta = last_modified_delta

    @property
    def state(self):
        """Gets the state of this ModelStatus.


        :return: The state of this ModelStatus.
        :rtype: AmberState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ModelStatus.


        :param state: The state of this ModelStatus.
        :type: AmberState
        """

        self._state = state

    @property
    def warning_level(self):
        """Gets the warning_level of this ModelStatus.

        Current Amber warning level, a measure of the compliance of recent behavior compared to behavior observed `Learning`.  - `0`: OK - `1`: asset changing - `2`: asset critical

        :return: The warning_level of this ModelStatus.
        :rtype: int
        """
        return self._warning_level

    @warning_level.setter
    def warning_level(self, warning_level):
        """Sets the warning_level of this ModelStatus.

        Current Amber warning level, a measure of the compliance of recent behavior compared to behavior observed `Learning`.  - `0`: OK - `1`: asset changing - `2`: asset critical

        :param warning_level: The warning_level of this ModelStatus.
        :type: int
        """

        self._warning_level = warning_level

    @property
    def sample_count(self):
        """Gets the sample_count of this ModelStatus.

        Total number of patterns processed since configuration.

        :return: The sample_count of this ModelStatus.
        :rtype: int
        """
        return self._sample_count

    @sample_count.setter
    def sample_count(self, sample_count):
        """Sets the sample_count of this ModelStatus.

        Total number of patterns processed since configuration.

        :param sample_count: The sample_count of this ModelStatus.
        :type: int
        """

        self._sample_count = sample_count

    @property
    def cluster_count(self):
        """Gets the cluster_count of this ModelStatus.

        Total number of clusters generated by patterns so far.

        :return: The cluster_count of this ModelStatus.
        :rtype: int
        """
        return self._cluster_count

    @cluster_count.setter
    def cluster_count(self, cluster_count):
        """Sets the cluster_count of this ModelStatus.

        Total number of clusters generated by patterns so far.

        :param cluster_count: The cluster_count of this ModelStatus.
        :type: int
        """

        self._cluster_count = cluster_count

    @property
    def progress(self):
        """Gets the progress of this ModelStatus.

        During `Buffering`, `Learning` and `Autotuning`: estimated progress through the current state as an integer percentage.  During `Monitoring`: this field does not apply.

        :return: The progress of this ModelStatus.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this ModelStatus.

        During `Buffering`, `Learning` and `Autotuning`: estimated progress through the current state as an integer percentage.  During `Monitoring`: this field does not apply.

        :param progress: The progress of this ModelStatus.
        :type: int
        """

        self._progress = progress

    @property
    def message(self):
        """Gets the message of this ModelStatus.

        Status description.

        :return: The message of this ModelStatus.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ModelStatus.

        Status description.

        :param message: The message of this ModelStatus.
        :type: str
        """

        self._message = message

    @property
    def last_modified(self):
        """Gets the last_modified of this ModelStatus.

        Unix time stamp of the last posted stream data

        :return: The last_modified of this ModelStatus.
        :rtype: int
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this ModelStatus.

        Unix time stamp of the last posted stream data

        :param last_modified: The last_modified of this ModelStatus.
        :type: int
        """

        self._last_modified = last_modified

    @property
    def last_modified_delta(self):
        """Gets the last_modified_delta of this ModelStatus.

        number of seconds since the last posted stream data

        :return: The last_modified_delta of this ModelStatus.
        :rtype: int
        """
        return self._last_modified_delta

    @last_modified_delta.setter
    def last_modified_delta(self, last_modified_delta):
        """Sets the last_modified_delta of this ModelStatus.

        number of seconds since the last posted stream data

        :param last_modified_delta: The last_modified_delta of this ModelStatus.
        :type: int
        """

        self._last_modified_delta = last_modified_delta

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MTraining(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'list[VersionNumber]',
        'm_geometric_plot_y': 'list[float]',
        'm_geometric_plot_x': 'list[float]',
        'm_cluster_growth': 'list[float]',
        'm_anomaly_indexes': 'list[float]'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'm_geometric_plot_y': 'm_GeometricPlotY',
        'm_geometric_plot_x': 'm_GeometricPlotX',
        'm_cluster_growth': 'm_ClusterGrowth',
        'm_anomaly_indexes': 'm_AnomalyIndexes'
    }

    def __init__(self, version_number=None, m_geometric_plot_y=None, m_geometric_plot_x=None, m_cluster_growth=None, m_anomaly_indexes=None):
        """MTraining - a model defined in Swagger"""
        self._version_number = None
        self._m_geometric_plot_y = None
        self._m_geometric_plot_x = None
        self._m_cluster_growth = None
        self._m_anomaly_indexes = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        self.m_geometric_plot_y = m_geometric_plot_y
        self.m_geometric_plot_x = m_geometric_plot_x
        self.m_cluster_growth = m_cluster_growth
        if m_anomaly_indexes is not None:
            self.m_anomaly_indexes = m_anomaly_indexes

    @property
    def version_number(self):
        """Gets the version_number of this MTraining.


        :return: The version_number of this MTraining.
        :rtype: list[VersionNumber]
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MTraining.


        :param version_number: The version_number of this MTraining.
        :type: list[VersionNumber]
        """

        self._version_number = version_number

    @property
    def m_geometric_plot_y(self):
        """Gets the m_geometric_plot_y of this MTraining.


        :return: The m_geometric_plot_y of this MTraining.
        :rtype: list[float]
        """
        return self._m_geometric_plot_y

    @m_geometric_plot_y.setter
    def m_geometric_plot_y(self, m_geometric_plot_y):
        """Sets the m_geometric_plot_y of this MTraining.


        :param m_geometric_plot_y: The m_geometric_plot_y of this MTraining.
        :type: list[float]
        """
        if m_geometric_plot_y is None:
            raise ValueError("Invalid value for `m_geometric_plot_y`, must not be `None`")

        self._m_geometric_plot_y = m_geometric_plot_y

    @property
    def m_geometric_plot_x(self):
        """Gets the m_geometric_plot_x of this MTraining.


        :return: The m_geometric_plot_x of this MTraining.
        :rtype: list[float]
        """
        return self._m_geometric_plot_x

    @m_geometric_plot_x.setter
    def m_geometric_plot_x(self, m_geometric_plot_x):
        """Sets the m_geometric_plot_x of this MTraining.


        :param m_geometric_plot_x: The m_geometric_plot_x of this MTraining.
        :type: list[float]
        """
        if m_geometric_plot_x is None:
            raise ValueError("Invalid value for `m_geometric_plot_x`, must not be `None`")

        self._m_geometric_plot_x = m_geometric_plot_x

    @property
    def m_cluster_growth(self):
        """Gets the m_cluster_growth of this MTraining.


        :return: The m_cluster_growth of this MTraining.
        :rtype: list[float]
        """
        return self._m_cluster_growth

    @m_cluster_growth.setter
    def m_cluster_growth(self, m_cluster_growth):
        """Sets the m_cluster_growth of this MTraining.


        :param m_cluster_growth: The m_cluster_growth of this MTraining.
        :type: list[float]
        """
        if m_cluster_growth is None:
            raise ValueError("Invalid value for `m_cluster_growth`, must not be `None`")

        self._m_cluster_growth = m_cluster_growth

    @property
    def m_anomaly_indexes(self):
        """Gets the m_anomaly_indexes of this MTraining.


        :return: The m_anomaly_indexes of this MTraining.
        :rtype: list[float]
        """
        return self._m_anomaly_indexes

    @m_anomaly_indexes.setter
    def m_anomaly_indexes(self, m_anomaly_indexes):
        """Sets the m_anomaly_indexes of this MTraining.


        :param m_anomaly_indexes: The m_anomaly_indexes of this MTraining.
        :type: list[float]
        """

        self._m_anomaly_indexes = m_anomaly_indexes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MTraining, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MTraining):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from boonamber.v2.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_model(self, model_id, **kwargs):  # noqa: E501
        """delete a model  # noqa: E501

        Permanently delete the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_model(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: DeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_model_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_model_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def delete_model_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """delete a model  # noqa: E501

        Permanently delete the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_model_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: DeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `delete_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model(self, model_id, **kwargs):  # noqa: E501
        """get model metadata  # noqa: E501

        Return metadata for the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get model metadata  # noqa: E501

        Return metadata for the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_config(self, model_id, **kwargs):  # noqa: E501
        """get model configuration  # noqa: E501

        Get the configuration of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_config(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: PostConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_config_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_config_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_config_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get model configuration  # noqa: E501

        Get the configuration of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_config_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: PostConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_diagnostic(self, model_id, **kwargs):  # noqa: E501
        """get the diagnostic of a model  # noqa: E501

        Get the current diagnostic of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_diagnostic(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_diagnostic_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_diagnostic_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_diagnostic_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get the diagnostic of a model  # noqa: E501

        Get the current diagnostic of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_diagnostic_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_diagnostic" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_diagnostic`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/diagnostic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=bytes,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_nano_status(self, model_id, **kwargs):  # noqa: E501
        """get current nano status of the model  # noqa: E501

        Get the current nano state of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_nano_status(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetNanoStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_nano_status_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_nano_status_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_nano_status_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get current nano status of the model  # noqa: E501

        Get the current nano state of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_nano_status_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetNanoStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_nano_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_nano_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/status/nano', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetNanoStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_pretrain(self, model_id, **kwargs):  # noqa: E501
        """get pretraining progress  # noqa: E501

        Get the pretraining status of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_pretrain(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetPretrainResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_pretrain_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_pretrain_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_pretrain_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get pretraining progress  # noqa: E501

        Get the pretraining status of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_pretrain_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetPretrainResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_pretrain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_pretrain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/pretrain', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetPretrainResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_root_cause(self, model_id, **kwargs):  # noqa: E501
        """perform root cause analysis  # noqa: E501

        Return a measure of the significance of each feature in the creation of a cluster. The values range from 0 to 1 where a relatively high value represents a feature that was influential in creating the new cluster. No conclusions can be drawn from values close to zero. This measure can be computed for existing clusters or for individual vectors directly.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_root_cause(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param str clusters: Clusters to analyze (list of comma-separated integers).
        :param str vectors: Vectors to analyze, as a flat list of comma-separated floats. Number of values must be a multiple of the configured number of features.
        :return: GetRootCauseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_root_cause_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_root_cause_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_root_cause_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """perform root cause analysis  # noqa: E501

        Return a measure of the significance of each feature in the creation of a cluster. The values range from 0 to 1 where a relatively high value represents a feature that was influential in creating the new cluster. No conclusions can be drawn from values close to zero. This measure can be computed for existing clusters or for individual vectors directly.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_root_cause_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param str clusters: Clusters to analyze (list of comma-separated integers).
        :param str vectors: Vectors to analyze, as a flat list of comma-separated floats. Number of values must be a multiple of the configured number of features.
        :return: GetRootCauseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id', 'clusters', 'vectors']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_root_cause" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_root_cause`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []
        if 'clusters' in params:
            query_params.append(('clusters', params['clusters']))  # noqa: E501
        if 'vectors' in params:
            query_params.append(('vectors', params['vectors']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/rootCause', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetRootCauseResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_status(self, model_id, **kwargs):  # noqa: E501
        """get current status of the model  # noqa: E501

        Get the current state and learning progress of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_status(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_status_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_status_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_status_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get current status of the model  # noqa: E501

        Get the current state and learning progress of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_status_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_summary(self, model_id, **kwargs):  # noqa: E501
        """get the summation of a model  # noqa: E501

        Get the current summation of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_summary(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetSummaryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_model_summary_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_model_summary_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def get_model_summary_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """get the summation of a model  # noqa: E501

        Get the current summation of the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_summary_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: GetSummaryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_summary" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model_summary`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSummaryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_models(self, **kwargs):  # noqa: E501
        """list all models  # noqa: E501

        Return `id` and `label` for all models belonging to the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_models(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_models_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_models_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_models_with_http_info(self, **kwargs):  # noqa: E501
        """list all models  # noqa: E501

        Return `id` and `label` for all models belonging to the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_models_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_models" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetModelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_version(self, **kwargs):  # noqa: E501
        """get version information  # noqa: E501

        Return version information for the API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_version(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_version_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_version_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_version_with_http_info(self, **kwargs):  # noqa: E501
        """get version information  # noqa: E501

        Return version information for the API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_version_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_version" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/version', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetVersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model(self, body, **kwargs):  # noqa: E501
        """create a model  # noqa: E501

        Create a new model and return its unique identifier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostModelRequest body: initial metadata for new model (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_model_with_http_info(self, body, **kwargs):  # noqa: E501
        """create a model  # noqa: E501

        Create a new model and return its unique identifier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostModelRequest body: initial metadata for new model (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_config(self, model_id, **kwargs):  # noqa: E501
        """configure a model  # noqa: E501

        Configure the specified model. Wipes all progress and puts the model in the `Buffering` state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_config(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostConfigRequest body: configuration to apply
        :return: PostConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_config_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_config_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def post_model_config_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """configure a model  # noqa: E501

        Configure the specified model. Wipes all progress and puts the model in the `Buffering` state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_config_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostConfigRequest body: configuration to apply
        :return: PostConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/config', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_copy(self, model_id, **kwargs):  # noqa: E501
        """make a copy of a model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_copy(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostModelCopyRequest body: copy request params
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_copy_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_copy_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def post_model_copy_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """make a copy of a model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_copy_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostModelCopyRequest body: copy request params
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_copy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_copy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/copy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_data(self, body, model_id, **kwargs):  # noqa: E501
        """send data to model and get back results  # noqa: E501

        Send data to the specified model, and get back the resulting analytics and model status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_data(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostDataRequest body: data vector or vectors as a flattened list of comma-separated values (required)
        :param str model_id: (required)
        :return: PostDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_data_with_http_info(body, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_data_with_http_info(body, model_id, **kwargs)  # noqa: E501
            return data

    def post_model_data_with_http_info(self, body, model_id, **kwargs):  # noqa: E501
        """send data to model and get back results  # noqa: E501

        Send data to the specified model, and get back the resulting analytics and model status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_data_with_http_info(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostDataRequest body: data vector or vectors as a flattened list of comma-separated values (required)
        :param str model_id: (required)
        :return: PostDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_model_data`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostDataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_learning(self, model_id, **kwargs):  # noqa: E501
        """update model configuration and re-enable learning  # noqa: E501

        Update model configuration and re-enable learning  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_learning(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostLearningRequest body: updates to apply
        :return: PostLearningResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_learning_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_learning_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def post_model_learning_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """update model configuration and re-enable learning  # noqa: E501

        Update model configuration and re-enable learning  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_learning_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :param PostLearningRequest body: updates to apply
        :return: PostLearningResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_learning" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_learning`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/learning', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostLearningResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_migrate(self, v1_model_id, **kwargs):  # noqa: E501
        """migrate a v1 sensor to a v2 model  # noqa: E501

        migrate a v1 sensor to a v2 model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_migrate(v1_model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str v1_model_id: version 1 model id (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_migrate_with_http_info(v1_model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_migrate_with_http_info(v1_model_id, **kwargs)  # noqa: E501
            return data

    def post_model_migrate_with_http_info(self, v1_model_id, **kwargs):  # noqa: E501
        """migrate a v1 sensor to a v2 model  # noqa: E501

        migrate a v1 sensor to a v2 model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_migrate_with_http_info(v1_model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str v1_model_id: version 1 model id (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['v1_model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_migrate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'v1_model_id' is set
        if ('v1_model_id' not in params or
                params['v1_model_id'] is None):
            raise ValueError("Missing the required parameter `v1_model_id` when calling `post_model_migrate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'v1_model_id' in params:
            path_params['v1ModelId'] = params['v1_model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{v1ModelId}/migrate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_outage(self, model_id, **kwargs):  # noqa: E501
        """call this after a data outage before resuming streaming  # noqa: E501

        Resets the streaming window generated by `streamingWindow`. This endpoint should be called after a data outage before resuming streaming.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_outage(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: Error
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_outage_with_http_info(model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_outage_with_http_info(model_id, **kwargs)  # noqa: E501
            return data

    def post_model_outage_with_http_info(self, model_id, **kwargs):  # noqa: E501
        """call this after a data outage before resuming streaming  # noqa: E501

        Resets the streaming window generated by `streamingWindow`. This endpoint should be called after a data outage before resuming streaming.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_outage_with_http_info(model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id: (required)
        :return: Error
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_outage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_outage`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/outage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Error',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_model_pretrain(self, body, model_id, **kwargs):  # noqa: E501
        """pretrain model with an existing dataset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_pretrain(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostPretrainRequest body: Data to use for pretraining. (required)
        :param str model_id: (required)
        :param str chunkspec: Chunk specifier for chunked uploads. In a chunked upload, each request is sent with a `chunkspec` of the form `1:3`, `2:10`, `7:7`, etc. where the first number is the index for the chunk being uploaded (1-based) and the second number is the total number of chunks in the transaction. The chunks may be uploaded in any order. Pretraining starts once all chunks have been received.
        :param str txn_id: Transaction id for chunked uploads. The response body for the first request in a chunked upload will contain a `txnId` which uniquely identifies the chunking transaction across multiple requests. That `txnId` must be included in the header of all remaining chunks uploaded in the transaction.
        :return: PostPretrainResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_model_pretrain_with_http_info(body, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_model_pretrain_with_http_info(body, model_id, **kwargs)  # noqa: E501
            return data

    def post_model_pretrain_with_http_info(self, body, model_id, **kwargs):  # noqa: E501
        """pretrain model with an existing dataset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_model_pretrain_with_http_info(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostPretrainRequest body: Data to use for pretraining. (required)
        :param str model_id: (required)
        :param str chunkspec: Chunk specifier for chunked uploads. In a chunked upload, each request is sent with a `chunkspec` of the form `1:3`, `2:10`, `7:7`, etc. where the first number is the index for the chunk being uploaded (1-based) and the second number is the total number of chunks in the transaction. The chunks may be uploaded in any order. Pretraining starts once all chunks have been received.
        :param str txn_id: Transaction id for chunked uploads. The response body for the first request in a chunked upload will contain a `txnId` which uniquely identifies the chunking transaction across multiple requests. That `txnId` must be included in the header of all remaining chunks uploaded in the transaction.
        :return: PostPretrainResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'model_id', 'chunkspec', 'txn_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_model_pretrain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_model_pretrain`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `post_model_pretrain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'chunkspec' in params:
            header_params['chunkspec'] = params['chunkspec']  # noqa: E501
        if 'txn_id' in params:
            header_params['txnId'] = params['txn_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/pretrain', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostPretrainResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_oauth2_access(self, body, **kwargs):  # noqa: E501
        """request an API token given license and secret key  # noqa: E501

        Request an Oauth2 Bearer token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_oauth2_access(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostOauth2AccessRequest body: Amber account credentials (required)
        :return: PostOauth2AccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_oauth2_access_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_oauth2_access_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_oauth2_access_with_http_info(self, body, **kwargs):  # noqa: E501
        """request an API token given license and secret key  # noqa: E501

        Request an Oauth2 Bearer token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_oauth2_access_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostOauth2AccessRequest body: Amber account credentials (required)
        :return: PostOauth2AccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_oauth2_access" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_oauth2_access`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/oauth2/access', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostOauth2AccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_oauth2_refresh(self, body, **kwargs):  # noqa: E501
        """request an API token given a refresh token  # noqa: E501

        Request an Oauth2 Bearer token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_oauth2_refresh(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostOauth2RefreshRequest body: Amber account credentials (required)
        :return: PostOauth2RefreshResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_oauth2_refresh_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_oauth2_refresh_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_oauth2_refresh_with_http_info(self, body, **kwargs):  # noqa: E501
        """request an API token given a refresh token  # noqa: E501

        Request an Oauth2 Bearer token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_oauth2_refresh_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostOauth2RefreshRequest body: Amber account credentials (required)
        :return: PostOauth2RefreshResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_oauth2_refresh" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_oauth2_refresh`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/oauth2/refresh', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostOauth2RefreshResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_model(self, body, model_id, **kwargs):  # noqa: E501
        """update model metadata  # noqa: E501

        Update metadata for the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_model(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PutModelRequest body: updates to apply (required)
        :param str model_id: (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_model_with_http_info(body, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.put_model_with_http_info(body, model_id, **kwargs)  # noqa: E501
            return data

    def put_model_with_http_info(self, body, model_id, **kwargs):  # noqa: E501
        """update model metadata  # noqa: E501

        Update metadata for the specified model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_model_with_http_info(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PutModelRequest body: updates to apply (required)
        :param str model_id: (required)
        :return: PostModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_model`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `put_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PostModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_model_data(self, body, model_id, **kwargs):  # noqa: E501
        """update fusion vector and get back results  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_model_data(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PutDataRequest body: updates to the fusion vector (required)
        :param str model_id: (required)
        :return: PutDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_model_data_with_http_info(body, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.put_model_data_with_http_info(body, model_id, **kwargs)  # noqa: E501
            return data

    def put_model_data_with_http_info(self, body, model_id, **kwargs):  # noqa: E501
        """update fusion vector and get back results  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_model_data_with_http_info(body, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PutDataRequest body: updates to the fusion vector (required)
        :param str model_id: (required)
        :return: PutDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_model_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_model_data`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `put_model_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/models/{modelId}/data', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PutDataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PostOauth2RefreshResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id_token': 'str',
        'token_type': 'str',
        'expires_in': 'str',
        'refresh_token': 'str'
    }

    attribute_map = {
        'id_token': 'idToken',
        'token_type': 'tokenType',
        'expires_in': 'expiresIn',
        'refresh_token': 'refreshToken'
    }

    def __init__(self, id_token=None, token_type=None, expires_in=None, refresh_token=None):
        """PostOauth2RefreshResponse - a model defined in Swagger"""
        self._id_token = None
        self._token_type = None
        self._expires_in = None
        self._refresh_token = None
        self.discriminator = None
        if id_token is not None:
            self.id_token = id_token
        if token_type is not None:
            self.token_type = token_type
        if expires_in is not None:
            self.expires_in = expires_in
        if refresh_token is not None:
            self.refresh_token = refresh_token

    @property
    def id_token(self):
        """Gets the id_token of this PostOauth2RefreshResponse.

        Authorization token. Requests to all API endpoints except `POST /oauth2` must include a valid token in a header field called `Authorization` with value `Bearer ${idToken}`.

        :return: The id_token of this PostOauth2RefreshResponse.
        :rtype: str
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this PostOauth2RefreshResponse.

        Authorization token. Requests to all API endpoints except `POST /oauth2` must include a valid token in a header field called `Authorization` with value `Bearer ${idToken}`.

        :param id_token: The id_token of this PostOauth2RefreshResponse.
        :type: str
        """

        self._id_token = id_token

    @property
    def token_type(self):
        """Gets the token_type of this PostOauth2RefreshResponse.

        Always `Bearer`.

        :return: The token_type of this PostOauth2RefreshResponse.
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this PostOauth2RefreshResponse.

        Always `Bearer`.

        :param token_type: The token_type of this PostOauth2RefreshResponse.
        :type: str
        """

        self._token_type = token_type

    @property
    def expires_in(self):
        """Gets the expires_in of this PostOauth2RefreshResponse.

        Number of seconds before `idToken` becomes invalid.

        :return: The expires_in of this PostOauth2RefreshResponse.
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this PostOauth2RefreshResponse.

        Number of seconds before `idToken` becomes invalid.

        :param expires_in: The expires_in of this PostOauth2RefreshResponse.
        :type: str
        """

        self._expires_in = expires_in

    @property
    def refresh_token(self):
        """Gets the refresh_token of this PostOauth2RefreshResponse.

        Can be used to refresh the `idToken` when it is nearing expiration.

        :return: The refresh_token of this PostOauth2RefreshResponse.
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this PostOauth2RefreshResponse.

        Can be used to refresh the `idToken` when it is nearing expiration.

        :param refresh_token: The refresh_token of this PostOauth2RefreshResponse.
        :type: str
        """

        self._refresh_token = refresh_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PostOauth2RefreshResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostOauth2RefreshResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetVersionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'release': 'str',
        'swagger_ui': 'str',
        'builder': 'str',
        'expert_api': 'str',
        'expert_common': 'str',
        'nano_secure': 'str',
        'amber_store': 'str',
        'mongolia': 'str'
    }

    attribute_map = {
        'api_version': 'api-version',
        'release': 'release',
        'swagger_ui': 'swagger-ui',
        'builder': 'builder',
        'expert_api': 'expert-api',
        'expert_common': 'expert-common',
        'nano_secure': 'nano-secure',
        'amber_store': 'amber-store',
        'mongolia': 'mongolia'
    }

    def __init__(self, api_version=None, release=None, swagger_ui=None, builder=None, expert_api=None, expert_common=None, nano_secure=None, amber_store=None, mongolia=None):
        """GetVersionResponse - a model defined in Swagger"""
        self._api_version = None
        self._release = None
        self._swagger_ui = None
        self._builder = None
        self._expert_api = None
        self._expert_common = None
        self._nano_secure = None
        self._amber_store = None
        self._mongolia = None
        self.discriminator = None
        if api_version is not None:
            self.api_version = api_version
        if release is not None:
            self.release = release
        if swagger_ui is not None:
            self.swagger_ui = swagger_ui
        if builder is not None:
            self.builder = builder
        if expert_api is not None:
            self.expert_api = expert_api
        if expert_common is not None:
            self.expert_common = expert_common
        if nano_secure is not None:
            self.nano_secure = nano_secure
        if amber_store is not None:
            self.amber_store = amber_store
        if mongolia is not None:
            self.mongolia = mongolia

    @property
    def api_version(self):
        """Gets the api_version of this GetVersionResponse.

        API version.

        :return: The api_version of this GetVersionResponse.
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this GetVersionResponse.

        API version.

        :param api_version: The api_version of this GetVersionResponse.
        :type: str
        """

        self._api_version = api_version

    @property
    def release(self):
        """Gets the release of this GetVersionResponse.

        Software release of server.

        :return: The release of this GetVersionResponse.
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this GetVersionResponse.

        Software release of server.

        :param release: The release of this GetVersionResponse.
        :type: str
        """

        self._release = release

    @property
    def swagger_ui(self):
        """Gets the swagger_ui of this GetVersionResponse.

        SHA-1 of Swagger UI.

        :return: The swagger_ui of this GetVersionResponse.
        :rtype: str
        """
        return self._swagger_ui

    @swagger_ui.setter
    def swagger_ui(self, swagger_ui):
        """Sets the swagger_ui of this GetVersionResponse.

        SHA-1 of Swagger UI.

        :param swagger_ui: The swagger_ui of this GetVersionResponse.
        :type: str
        """

        self._swagger_ui = swagger_ui

    @property
    def builder(self):
        """Gets the builder of this GetVersionResponse.

        SHA-1 of `builder`.

        :return: The builder of this GetVersionResponse.
        :rtype: str
        """
        return self._builder

    @builder.setter
    def builder(self, builder):
        """Sets the builder of this GetVersionResponse.

        SHA-1 of `builder`.

        :param builder: The builder of this GetVersionResponse.
        :type: str
        """

        self._builder = builder

    @property
    def expert_api(self):
        """Gets the expert_api of this GetVersionResponse.

        SHA-1 of `expert-api`.

        :return: The expert_api of this GetVersionResponse.
        :rtype: str
        """
        return self._expert_api

    @expert_api.setter
    def expert_api(self, expert_api):
        """Sets the expert_api of this GetVersionResponse.

        SHA-1 of `expert-api`.

        :param expert_api: The expert_api of this GetVersionResponse.
        :type: str
        """

        self._expert_api = expert_api

    @property
    def expert_common(self):
        """Gets the expert_common of this GetVersionResponse.

        SHA-1 of `expert-common`.

        :return: The expert_common of this GetVersionResponse.
        :rtype: str
        """
        return self._expert_common

    @expert_common.setter
    def expert_common(self, expert_common):
        """Sets the expert_common of this GetVersionResponse.

        SHA-1 of `expert-common`.

        :param expert_common: The expert_common of this GetVersionResponse.
        :type: str
        """

        self._expert_common = expert_common

    @property
    def nano_secure(self):
        """Gets the nano_secure of this GetVersionResponse.

        SHA-1 of `nano-secure`.

        :return: The nano_secure of this GetVersionResponse.
        :rtype: str
        """
        return self._nano_secure

    @nano_secure.setter
    def nano_secure(self, nano_secure):
        """Sets the nano_secure of this GetVersionResponse.

        SHA-1 of `nano-secure`.

        :param nano_secure: The nano_secure of this GetVersionResponse.
        :type: str
        """

        self._nano_secure = nano_secure

    @property
    def amber_store(self):
        """Gets the amber_store of this GetVersionResponse.

        SHA-1 of `amber-store`.

        :return: The amber_store of this GetVersionResponse.
        :rtype: str
        """
        return self._amber_store

    @amber_store.setter
    def amber_store(self, amber_store):
        """Sets the amber_store of this GetVersionResponse.

        SHA-1 of `amber-store`.

        :param amber_store: The amber_store of this GetVersionResponse.
        :type: str
        """

        self._amber_store = amber_store

    @property
    def mongolia(self):
        """Gets the mongolia of this GetVersionResponse.

        SHA-1 of `mongolia`.

        :return: The mongolia of this GetVersionResponse.
        :rtype: str
        """
        return self._mongolia

    @mongolia.setter
    def mongolia(self, mongolia):
        """Sets the mongolia of this GetVersionResponse.

        SHA-1 of `mongolia`.

        :param mongolia: The mongolia of this GetVersionResponse.
        :type: str
        """

        self._mongolia = mongolia

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetVersionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetVersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Model(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'label': 'str',
        'created': 'str',
        'modified': 'str'
    }

    attribute_map = {
        'id': 'id',
        'label': 'label',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, id=None, label=None, created=None, modified=None):
        """Model - a model defined in Swagger"""
        self._id = None
        self._label = None
        self._created = None
        self._modified = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if label is not None:
            self.label = label
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def id(self):
        """Gets the id of this Model.

        Unique identifier for model.

        :return: The id of this Model.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Model.

        Unique identifier for model.

        :param id: The id of this Model.
        :type: str
        """

        self._id = id

    @property
    def label(self):
        """Gets the label of this Model.

        Free-form label for this model.

        :return: The label of this Model.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Model.

        Free-form label for this model.

        :param label: The label of this Model.
        :type: str
        """

        self._label = label

    @property
    def created(self):
        """Gets the created of this Model.

        Model creation time in ISO format.

        :return: The created of this Model.
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Model.

        Model creation time in ISO format.

        :param created: The created of this Model.
        :type: str
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this Model.

        Last time model was updated, in ISO format.

        :return: The modified of this Model.
        :rtype: str
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Model.

        Last time model was updated, in ISO format.

        :param modified: The modified of this Model.
        :type: str
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Model, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Model):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .v1 import AmberV1Client as acv1
from .v1 import float_list_to_csv_string
from .v2.amber_client import AmberV2Client as acv2
from boonamber.v2.models import *
from .util.ambererror import AmberCloudError, AmberUserError
from .v2.rest import ApiException

import glob
import os


# version 1 Amberclient
class AmberClient(acv1):
    pass


class AmberV1Client(acv1):
    pass


# version 2 Amberclient
class AmberV2Client(acv2):
    pass


__pdoc__ = {}
__pdoc__["boonamber.v2.api"] = False
__pdoc__["boonamber.v2.api_client"] = False
__pdoc__["boonamber.v2.rest"] = False
__pdoc__["boonamber.v2.configuration"] = False
__pdoc__["boonamber.util"] = False
__pdoc__["AmberClient"] = False

in_files = glob.glob("boonamber/v2/models/*.py")
for model in in_files:
    tmp_func = os.path.splitext(os.path.basename(model))[0].title().replace("_", "")
    __pdoc__["{}.{}.attribute_map".format(os.path.splitext(model)[0].replace("/", "."), tmp_func)] = False
    __pdoc__["{}.{}.swagger_types".format(os.path.splitext(model)[0].replace("/", "."), tmp_func)] = False

# put model (so not to confuse with update_model)
__pdoc__["boonamber.v2.models.put_model_request"] = False

# post model copy (so as not to confuse with copy_model)
__pdoc__["boonamber.v2.models.post_model_copy_request"] = False

# oauth
__pdoc__["boonamber.v2.models.post_oauth2_access_request"] = False
__pdoc__["boonamber.v2.models.post_oauth2_refresh_request"] = False
__pdoc__["boonamber.v2.models.post_oauth2_access_response"] = False
__pdoc__["boonamber.v2.models.post_oauth2_refresh_response"] = False

# summary
__pdoc__["boonamber.v2.models.get_summary_response"] = False
__pdoc__["boonamber.v2.models.magic_number"] = False
__pdoc__["boonamber.v2.models.version_number"] = False
__pdoc__["boonamber.v2.models.m_buffer_stats"] = False
__pdoc__["boonamber.v2.models.m_autotune"] = False
__pdoc__["boonamber.v2.models.m_streaming_parameters"] = False
__pdoc__["boonamber.v2.models.m_amber_status"] = False
__pdoc__["boonamber.v2.models.m_training"] = False
__pdoc__["boonamber.v2.models.m_recent_samples"] = False
__pdoc__["boonamber.v2.models.m_recent_times"] = False
__pdoc__["boonamber.v2.models.m_recent_floats"] = False
__pdoc__["boonamber.v2.models.m_recent_ids"] = False
__pdoc__["boonamber.v2.models.m_pattern_memory"] = False
__pdoc__["boonamber.v2.models.m_recent_ams"] = False
__pdoc__["boonamber.v2.models.m_recent_analytics"] = False

__pdoc__["boonamber.v2.models.mncp"] = False
__pdoc__["boonamber.v2.models.map"] = False
__pdoc__["boonamber.v2.models.m_nano"] = False
__pdoc__["boonamber.v2.models.m_streaming_parameters"] = False
__pdoc__["boonamber.v2.models.m_nano_backend"] = False
__pdoc__["boonamber.v2.models.m_nano_config"] = False
